@@ -1,8 +1,8 @@
 use k8s_openapi::{api::apps::v1::Deployment, chrono::Utc};
 
-use super::{models::ResourceToYaml, utils};
+use super::{models::KubeResource, utils};
 
-#[derive(Clone)]
+#[derive(Clone, Debug, PartialEq)]
 pub struct KubeDeployment {
   pub name: String,
   pub namespace: String,
@@ -13,8 +13,8 @@ pub struct KubeDeployment {
   k8s_obj: Deployment,
 }
 
-impl KubeDeployment {
-  pub fn from_api(deployment: &Deployment) -> Self {
+impl KubeResource<Deployment> for KubeDeployment {
+  fn from_api(deployment: &Deployment) -> Self {
     let (ready, available, updated) = match &deployment.status {
       Some(s) => (
         format!(
@@ -38,9 +38,7 @@ impl KubeDeployment {
       k8s_obj: deployment.to_owned(),
     }
   }
-}
 
-impl ResourceToYaml<Deployment> for KubeDeployment {
   fn get_k8s_obj(&self) -> &Deployment {
     &self.k8s_obj
   }
@@ -48,5 +46,26 @@ impl ResourceToYaml<Deployment> for KubeDeployment {
 
 #[cfg(test)]
 mod tests {
-  // TODO
+  use super::super::test_utils::{convert_resource_from_file, get_time};
+  use super::*;
+
+  #[test]
+  fn test_deployments_from_api() {
+    let (deployments, deployment_list): (Vec<KubeDeployment>, Vec<_>) =
+      convert_resource_from_file("deployments");
+
+    assert_eq!(deployments.len(), 4);
+    assert_eq!(
+      deployments[0],
+      KubeDeployment {
+        name: "metrics-server".into(),
+        namespace: "kube-system".into(),
+        age: utils::to_age(Some(&get_time("2021-05-10T21:48:06Z")), Utc::now()),
+        k8s_obj: deployment_list[0].clone(),
+        available: 1,
+        updated: 1,
+        ready: "1/1".into(),
+      }
+    );
+  }
 }
