@@ -2,14 +2,11 @@ use k8s_openapi::{
   api::core::v1::{Node, Pod},
   chrono::Utc,
 };
-use kube::{
-  api::{DynamicObject, ObjectList},
-  Error,
-};
+use kube::api::{DynamicObject, ObjectList};
 use tokio::sync::MutexGuard;
 
 use super::{
-  models::ResourceToYaml,
+  models::KubeResource,
   utils::{self, UNKNOWN},
   App,
 };
@@ -23,7 +20,7 @@ pub struct NodeMetrics {
   pub mem_percent: f64,
 }
 
-#[derive(Clone)]
+#[derive(Clone, Debug, PartialEq)]
 pub struct KubeNode {
   pub name: String,
   pub status: String,
@@ -45,9 +42,9 @@ static NODE_LABEL_ROLE: &str = "kubernetes.io/role";
 static NONE_ROLE: &str = "<none>";
 
 impl KubeNode {
-  pub fn from_api(
+  pub fn from_api_with_pods(
     node: &Node,
-    pods_list: &Result<ObjectList<Pod>, Error>,
+    pods_list: &ObjectList<Pod>,
     app: &mut MutexGuard<App>,
   ) -> Self {
     let node_name = node.metadata.name.clone().unwrap_or_default();
@@ -89,13 +86,10 @@ impl KubeNode {
       None => (None, None, None, None),
     };
 
-    let pod_count = match &pods_list {
-      Ok(pods) => pods.iter().fold(0, |acc, pod| {
-        let p_node_name = pod.spec.as_ref().and_then(|spec| spec.node_name.clone());
-        p_node_name.map_or(acc, |v| if v == node_name { acc + 1 } else { acc })
-      }),
-      _ => 0,
-    };
+    let pod_count = pods_list.iter().fold(0, |acc, pod| {
+      let p_node_name = pod.spec.as_ref().and_then(|spec| spec.node_name.clone());
+      p_node_name.map_or(acc, |v| if v == node_name { acc + 1 } else { acc })
+    });
 
     let role = match &node.metadata.labels {
       Some(labels) => labels
@@ -168,10 +162,14 @@ impl KubeNode {
   }
 }
 
-impl ResourceToYaml<Node> for KubeNode {
+impl KubeResource<Node> for KubeNode {
   fn get_k8s_obj(&self) -> &Node {
     &self.k8s_obj
   }
+
+  fn from_api(_item: &Node) -> Self {
+    unimplemented!()
+  }
 }
 
 impl NodeMetrics {
@@ -205,5 +203,50 @@ impl NodeMetrics {
 
 #[cfg(test)]
 mod tests {
-  // TODO
+  use tokio::sync::Mutex;
+
+  use super::super::test_utils::{get_time, load_resource_from_file};
+  use super::*;
+
+  #[tokio::test]
+  async fn test_stateful_sets_from_api() {
+    let nodes = load_resource_from_file("nodes");
+    let node_list = nodes.items.clone();
+    let pods_list = load_resource_from_file("pods");
+    let mut app = App::default();
+    app.data.node_metrics = vec![NodeMetrics {
+      name: "gke-hello-hipster-default-pool-9e6f6ffb-q16l".into(),
+      cpu: "1414m".into(),
+      cpu_percent: 0f64,
+      mem: "590Mi".into(),
+      mem_percent: 0f64,
+    }];
+    let app = Mutex::new(app);
+    let mut app = app.lock().await;
+
+    let nodes = nodes
+      .iter()
+      .map(|it| KubeNode::from_api_with_pods(it, &pods_list, &mut app))
+      .collect::<Vec<_>>();
+
+    assert_eq!(nodes.len(), 1);
+    assert_eq!(
+      nodes[0],
+      KubeNode {
+        name: "gke-hello-hipster-default-pool-9e6f6ffb-q16l".into(),
+        age: utils::to_age(Some(&get_time("2021-05-10T21:48:07Z")), Utc::now()),
+        k8s_obj: node_list[0].clone(),
+        status: "Ready".into(),
+        role: "control-plane,master".into(),
+        version: "v1.20.6+k3s1".into(),
+        pods: 5,
+        cpu: "1414m".into(),
+        mem: "590Mi".into(),
+        cpu_a: "8000m".into(),
+        mem_a: "31967Mi".into(),
+        cpu_percent: "17".into(),
+        mem_percent: "1".into(),
+      }
+    );
+  }
 }
