@@ -1,7 +1,7 @@
 use crossterm::event::{MouseEvent, MouseEventKind};
 use serde::Serialize;
 
-use crate::app::models::ResourceToYaml;
+use crate::app::models::KubeResource;
 
 use super::app::{
   key_binding::DEFAULT_KEYBINDING,
@@ -18,13 +18,13 @@ pub async fn handle_key_events(key: Key, app: &mut App) {
     _ if key == DEFAULT_KEYBINDING.esc.key => {
       handle_escape(app);
     }
-    _ if key == DEFAULT_KEYBINDING.quit.key => {
+    _ if key == DEFAULT_KEYBINDING.quit.key || key == DEFAULT_KEYBINDING.quit.alt.unwrap() => {
       app.should_quit = true;
     }
-    _ if key == DEFAULT_KEYBINDING.down.key => {
+    _ if key == DEFAULT_KEYBINDING.down.key || key == DEFAULT_KEYBINDING.down.alt.unwrap() => {
       handle_scroll(app, true, false).await;
     }
-    _ if key == DEFAULT_KEYBINDING.up.key => {
+    _ if key == DEFAULT_KEYBINDING.up.key || key == DEFAULT_KEYBINDING.up.alt.unwrap() => {
       handle_scroll(app, false, false).await;
     }
     _ if key == DEFAULT_KEYBINDING.toggle_theme.key => {
@@ -34,7 +34,7 @@ pub async fn handle_key_events(key: Key, app: &mut App) {
       app.refresh();
     }
     _ if key == DEFAULT_KEYBINDING.help.key => {
-      app.push_navigation_stack(RouteId::HelpMenu, ActiveBlock::Empty)
+      app.push_navigation_stack(RouteId::HelpMenu, ActiveBlock::Help)
     }
     _ if key == DEFAULT_KEYBINDING.jump_to_all_context.key => {
       app.route_contexts();
@@ -86,7 +86,7 @@ async fn handle_describe_or_yaml_action<T, S>(
   action: IoCmdEvent,
 ) -> bool
 where
-  T: ResourceToYaml<S>,
+  T: KubeResource<S>,
   S: Serialize,
 {
   if key == DEFAULT_KEYBINDING.describe_resource.key {
@@ -111,14 +111,16 @@ async fn handle_route_events(key: Key, app: &mut App) {
     // handle resource tabs on overview
     RouteId::Home => {
       match key {
-        _ if key == DEFAULT_KEYBINDING.right.key => {
+        _ if key == DEFAULT_KEYBINDING.right.key
+          || key == DEFAULT_KEYBINDING.right.alt.unwrap() =>
+        {
           app.context_tabs.next();
           app.push_navigation_stack(
             RouteId::Home,
             app.context_tabs.active_block.unwrap_or(ActiveBlock::Empty),
           );
         }
-        _ if key == DEFAULT_KEYBINDING.left.key => {
+        _ if key == DEFAULT_KEYBINDING.left.key || key == DEFAULT_KEYBINDING.left.alt.unwrap() => {
           app.context_tabs.previous();
           app.push_navigation_stack(
             RouteId::Home,
@@ -300,8 +302,10 @@ async fn handle_route_events(key: Key, app: &mut App) {
             .await;
           }
         }
-        ActiveBlock::Contexts | ActiveBlock::Utilization | ActiveBlock::Empty => { /* Do nothing */
-        }
+        ActiveBlock::Contexts
+        | ActiveBlock::Utilization
+        | ActiveBlock::Empty
+        | ActiveBlock::Help => { /* Do nothing */ }
       }
     }
     RouteId::Contexts => {
@@ -391,6 +395,7 @@ async fn handle_scroll(app: &mut App, down: bool, is_mouse: bool) {
         app.data.describe_out.scroll_up();
       }
     }
+    ActiveBlock::Help => handle_table_scroll(&mut app.help_docs, down),
     ActiveBlock::Empty => { /* Do nothing */ }
   }
 }
